@@ -1,10 +1,11 @@
 k_JADE <- function(X, k=1, eps = 1e-06, maxiter = 100, na.action = na.fail)
 {
   X <- na.action(X)
-  #if (!all(sapply(X, is.numeric)))  stop("'X' must be numeric")
+  if (!all(sapply(X, is.numeric)))  stop("'X' must be numeric")
   
   X <- as.matrix(X)
- 
+  data.X <- X 
+
   n <- nrow(X)
   p <- ncol(X)   
 
@@ -13,7 +14,7 @@ k_JADE <- function(X, k=1, eps = 1e-06, maxiter = 100, na.action = na.fail)
 
   W0 <- FOBI(X)$W
  
-  Z <- X%*%t(W0) 
+  Z <- tcrossprod(X,W0) 
 
   CM <- array(0,c(p,p,sum((p-k+1):p)))
   R <- diag(p)
@@ -40,10 +41,25 @@ k_JADE <- function(X, k=1, eps = 1e-06, maxiter = 100, na.action = na.fail)
     }
    }
   }
-  V<-rjd.fortran(CM,maxiter=maxiter,eps=eps)$V
+  V<-t(rjd.fortran(CM,maxiter=maxiter,eps=eps)$V)
  
-  W <- t(V)%*%W0
-  S <- X %*% t(W)
+  Z<-tcrossprod(X,V)
+ 
+  kurt <- rep(0,p)
+  for(j in 1:p){
+    kurt[j] <- mean(Z[,j]^4)-3
+  }
+
+  P <- matrix(0,p,p)
+  ord <- order(kurt,decreasing=TRUE) 
+  for(j in 1:p){ 
+    P[j,ord[j]] <- 1
+  }  
+
+  B <- P%*%V%*%W0
+
+  W <- V%*%W0
+  S <- tcrossprod(data.X,W)
   A <- solve(W)
   colnames(S) <- paste("IC.", 1:p, sep="")
   res<-list(A=A, W=W, S=S, Xmu=Col.center)
